==> cxf-testutils-2.4.9.jbossorg-1-sources.jar: org/apache/schema_validation/types/ObjectFactory.java <==

package org.apache.schema_validation.types;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.schema_validation.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.schema_validation.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SetComplexStruct }
     * 
     */
    public SetComplexStruct createSetComplexStruct() {
        return new SetComplexStruct();
    }

    /**
     * Create an instance of {@link ComplexStruct }
     * 
     */
    public ComplexStruct createComplexStruct() {
        return new ComplexStruct();
    }

    /**
     * Create an instance of {@link SetOccuringStruct }
     * 
     */
    public SetOccuringStruct createSetOccuringStruct() {
        return new SetOccuringStruct();
    }

    /**
     * Create an instance of {@link OccuringStruct }
     * 
     */
    public OccuringStruct createOccuringStruct() {
        return new OccuringStruct();
    }

    /**
     * Create an instance of {@link GetComplexStruct }
     * 
     */
    public GetComplexStruct createGetComplexStruct() {
        return new GetComplexStruct();
    }

    /**
     * Create an instance of {@link SetOccuringStructResponse }
     * 
     */
    public SetOccuringStructResponse createSetOccuringStructResponse() {
        return new SetOccuringStructResponse();
    }

    /**
     * Create an instance of {@link SetComplexStructResponse }
     * 
     */
    public SetComplexStructResponse createSetComplexStructResponse() {
        return new SetComplexStructResponse();
    }

    /**
     * Create an instance of {@link GetComplexStructResponse }
     * 
     */
    public GetComplexStructResponse createGetComplexStructResponse() {
        return new GetComplexStructResponse();
    }

    /**
     * Create an instance of {@link GetOccuringStructResponse }
     * 
     */
    public GetOccuringStructResponse createGetOccuringStructResponse() {
        return new GetOccuringStructResponse();
    }

    /**
     * Create an instance of {@link GetOccuringStruct }
     * 
     */
    public GetOccuringStruct createGetOccuringStruct() {
        return new GetOccuringStruct();
    }

}

==> cxf-testutils-2.6.6.jbossorg-1-sources.jar: org/apache/schema_validation/types/ObjectFactory.java <==

package org.apache.schema_validation.types;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.schema_validation.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.schema_validation.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SetComplexStruct }
     * 
     */
    public SetComplexStruct createSetComplexStruct() {
        return new SetComplexStruct();
    }

    /**
     * Create an instance of {@link SomeRequest }
     * 
     */
    public SomeRequest createSomeRequest() {
        return new SomeRequest();
    }

    /**
     * Create an instance of {@link OccuringStruct }
     * 
     */
    public OccuringStruct createOccuringStruct() {
        return new OccuringStruct();
    }

    /**
     * Create an instance of {@link SetOccuringStructResponse }
     * 
     */
    public SetOccuringStructResponse createSetOccuringStructResponse() {
        return new SetOccuringStructResponse();
    }

    /**
     * Create an instance of {@link SetOccuringStruct }
     * 
     */
    public SetOccuringStruct createSetOccuringStruct() {
        return new SetOccuringStruct();
    }

    /**
     * Create an instance of {@link ComplexStruct }
     * 
     */
    public ComplexStruct createComplexStruct() {
        return new ComplexStruct();
    }

    /**
     * Create an instance of {@link SetComplexStructResponse }
     * 
     */
    public SetComplexStructResponse createSetComplexStructResponse() {
        return new SetComplexStructResponse();
    }

    /**
     * Create an instance of {@link GetComplexStruct }
     * 
     */
    public GetComplexStruct createGetComplexStruct() {
        return new GetComplexStruct();
    }

    /**
     * Create an instance of {@link GetOccuringStruct }
     * 
     */
    public GetOccuringStruct createGetOccuringStruct() {
        return new GetOccuringStruct();
    }

    /**
     * Create an instance of {@link SomeResponse }
     * 
     */
    public SomeResponse createSomeResponse() {
        return new SomeResponse();
    }

    /**
     * Create an instance of {@link GetOccuringStructResponse }
     * 
     */
    public GetOccuringStructResponse createGetOccuringStructResponse() {
        return new GetOccuringStructResponse();
    }

    /**
     * Create an instance of {@link GetComplexStructResponse }
     * 
     */
    public GetComplexStructResponse createGetComplexStructResponse() {
        return new GetComplexStructResponse();
    }

}
